/**
 * Copyright (c) 2008 Sonatype, Inc. All rights reserved.
 *
 * This program is licensed to you under the Apache License Version 2.0,
 * and you may not use this file except in compliance with the Apache License Version 2.0.
 * You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the Apache License Version 2.0 is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.webdav.method;

import org.sonatype.webdav.MethodExecutionContext;
import org.sonatype.webdav.UnauthorizedException;

import java.io.IOException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;


/**
 * Webdav OPTIONS method.
 * 
 * @author Andrew Williams
 * @version $Id: Options.java 697 2009-01-07 17:34:25Z juven $
 * @plexus.component role="org.sonatype.webdav.Method" role-hint="options"
 * @since 1.0
 */
public class Options
    extends AbstractWebdavMethod
{
    public void execute( MethodExecutionContext context, HttpServletRequest req, HttpServletResponse res )
        throws IOException, UnauthorizedException
    {
        if ( !authorizeRead( context.getUser(), res ) )
        {
            return;
        }

        res.addHeader( "DAV", "1,2" );

        StringBuffer methodsAllowed = determineMethodsAllowed( context, resourceCollection, req );

        res.addHeader( "Allow", methodsAllowed.toString() );
        res.addHeader( "MS-Author-Via", "DAV" );
    }
}
